@@ -1,5 +1,5 @@
 import socket
-import pydaikin.entity as entity
+
 import netifaces
 
 UDP_SRC_PORT = 30000
@@ -11,16 +11,18 @@ GRACE_SECONDS = 1
 DISCOVERY_MSG = "DAIKIN_UDP/common/basic_info"
 
 
-class DiscoveredObject(entity.Entity):
+class DiscoveredObject:
     def __init__(self, ip, port, basic_info_string):
-        entity.Entity.__init__(self)
+        self.values = {}
 
         self.values['ip'] = ip
         self.values['port'] = port
         self.values.update(self.parse_basic_info(basic_info_string))
 
     def parse_basic_info(self, basic_info):
-        d = self.parse_response(basic_info)
+        from pydaikin.daikin_base import Appliance
+
+        d = Appliance.parse_response(basic_info)
 
         if 'mac' not in d:
             raise ValueError("no mac found for device")
